# Changelog

<!--next-version-placeholder-->

## v0.1.6 (2022-07-09)
### Fix
* Attributes for all paragraph combined with attributes on word ([`8bc1809`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/8bc1809ae8b84f3f82067e7a59b9e656ca7bb95f))

### Documentation
* Add conda environment ([`c11caa7`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/c11caa7c4070e6b0e9d375c07aa7f09ba99d08fc))
* Add example and info ([`ea9a5c5`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/ea9a5c5a7c934dfd6ca38efa768b7bf35f26b97c))

## v0.1.5 (2022-07-09)
### Fix
* Hotfix entrypoints ([`231128a`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/231128af78afdc14c085ade7334264d8b8bad18f))

## v0.1.4 (2022-07-09)
### Fix
* Remove uncessary requirements ([`deb799b`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/deb799b0730481b8bd43fb5fe5f1a7b985f48e08))

### Documentation
* Typo ([`5c269c6`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/5c269c69edcffc06c11d1a63ef865b5383e95e52))
* Typo ([`a7b3abd`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/a7b3abdac045895dc845eca470410963b5aae17e))
* Typo ([`2e08fb7`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/2e08fb702b187e4256fa93004290bd1851258160))

## v0.1.3 (2022-07-09)
### Documentation
* Add example ([`d86458c`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/d86458c3bac2824d13d2f6bc9541221448b97d88))

## v0.1.2 (2022-07-09)
### Fix
* A bunch of hot fix ([`4f57944`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/4f57944d3e08e90d823c8237f861743d4c90c9be))

## v0.1.1 (2022-07-07)
### Fix
* No hashtags convertion in code_blocks ([`7742922`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/7742922f8c85208907c306337cb7b8fb245b0d79))

## v0.1.0 (2022-06-28)
### Feature
* Create the plugin ([`702dddf`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/702dddf8490bfd82fe8cdd8b77ce65ea46373a0c))

### Documentation
* Create and complete readme ([`2016003`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/2016003eb8c319be2cb419dd4e762c66ddf8ec74))
